import { r as registerInstance, e as createEvent, h, g as getElement } from './index-35278baa.js';
import { A as AV_API_KEY } from './global-86106bed.js';

const stockFinderCss = "";

const StockFinder = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.flySymbolSelected = createEvent(this, "flySymbolSelected", 7);
    this.searchResults = [];
    this.isLoading = false;
  }
  onFindStock(event) {
    event.preventDefault();
    const stockName = this.stockNameInput.value;
    this.isLoading = true;
    fetch(`https://www.alphavantage.co/query?function=SYMBOL_SEARCH&keywords=${stockName}&apikey=${AV_API_KEY}`)
      .then(res => res.json())
      .then(data => {
      this.searchResults = data.bestMatches.map(match => {
        return {
          name: match['2. name'],
          symbol: match['1. symbol'],
        };
      });
      this.isLoading = false;
    })
      .catch(err => {
      console.error('Error', err);
      this.isLoading = false;
    });
  }
  onSelectSymbol(symbol) {
    this.flySymbolSelected.emit(symbol);
  }
  render() {
    let content = (h("ul", null, this.searchResults.map(item => {
      return (h("li", { key: item.symbol, onClick: this.onSelectSymbol.bind(this, item.symbol) }, item.symbol, " - ", item.name));
    })));
    if (this.isLoading) {
      content = h("fly-spinner", null);
    }
    return (h("div", { class: "stock-finder" }, h("form", { onSubmit: this.onFindStock.bind(this) }, h("input", { id: "stock-symbol-finder", ref: el => (this.stockNameInput = el) }), h("button", { type: "submit" }, " Find ")), content));
  }
  get el() { return getElement(this); }
};
StockFinder.style = stockFinderCss;

export { StockFinder as fly_stock_finder };
