import { r as registerInstance, h, g as getElement, f as Host } from './index-35278baa.js';
import { A as AV_API_KEY } from './global-86106bed.js';

const stockPriceCss = "";

const StockPrice = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.isStockInputValid = false;
    this.isLoading = false;
    this.onUserInput = (event) => {
      this.stockUserInput = event.target.value;
      if (this.stockUserInput.trim() !== '') {
        this.isStockInputValid = true;
      }
      else {
        this.isStockInputValid = false;
      }
    };
  }
  stockSymbolChanged(newValue, oldValue) {
    if (newValue !== oldValue) {
      this.stockUserInput = newValue;
      this.isStockInputValid = true;
      this.fetchStockPrice(newValue);
    }
  }
  // LifeCycles from stencils
  componentWillLoad() { }
  componentDidLoad() {
    if (this.stockSymbol) {
      this.initialStockSymbol = this.stockSymbol;
      this.stockUserInput = this.stockSymbol;
      this.isStockInputValid = true;
      this.fetchStockPrice(this.stockSymbol);
    }
  }
  componentWillUpdate() { }
  componentDidUpdate() {
    // if (this.stockSymbol !== this.initialStockSymbol) {
    //   this.fetchStockPrice(this.stockSymbol);
    // }
  }
  disconnectedCallback() { }
  onStockSymbolSelected(event) {
    // listening from another web component
    // Listen simply listen events inside this component scope, So listening from
    // another component we need to add extra flags as below:::
    // if adding body:flySymbolSelected -> If this added then this emitted event  will buddle
    //  till body and then it can listen the event in here,,,,
    if (event.detail && event.detail !== this.stockSymbol) {
      this.stockSymbol = event.detail;
    }
  }
  fetchStockPrice(stockSymbol) {
    const url = `https://www.alphavantage.co/query?function=GLOBAL_QUOTE&symbol=${stockSymbol}&apikey=${AV_API_KEY}`;
    this.isLoading = true;
    fetch(url)
      .then(res => {
      if (res.status !== 200) {
        throw new Error('Invalid');
      }
      return res.json();
    })
      .then(data => {
      if (!data['Global Quote']['05. price']) {
        throw new Error('Invalid Symbol');
      }
      var a = +data['Global Quote']['05. price'];
      this.fetchPrice = a;
      this.error = null;
      this.isLoading = false;
    })
      .catch(err => {
      this.error = err.message;
      this.fetchPrice = null;
      this.isLoading = false;
    });
  }
  onFetchStockPrice(event) {
    // const stockSymbol = (this.el.shadowRoot.querySelector('#stock-symbol') as HTMLInputElement).value;
    event.preventDefault();
    this.stockSymbol = this.stockInput.value;
    this.fetchStockPrice(this.stockSymbol);
  }
  //Add classes dynamically
  hostData() {
    return { class: this.error ? 'error' : '' };
  }
  __stencil_render() {
    let dataContent = h("p", null, "Please enter a symbol");
    if (this.error) {
      dataContent = h("p", null, "ERROR : ", this.error);
    }
    if (!this.error && this.fetchPrice) {
      dataContent = h("p", null, "Price : ", this.fetchPrice);
    }
    if (this.isLoading) {
      dataContent = h("fly-spinner", null);
    }
    return (h("div", { class: "stock-price" }, h("form", { onSubmit: this.onFetchStockPrice.bind(this) }, h("input", { id: "stock-symbol", ref: el => (this.stockInput = el), value: this.stockUserInput, onInput: this.onUserInput }), h("button", { type: "submit", disabled: !this.isStockInputValid }, "Fetch")), h("div", null, dataContent)));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "stockSymbol": ["stockSymbolChanged"]
  }; }
  render() { return h(Host, this.hostData(), this.__stencil_render()); }
};
StockPrice.style = stockPriceCss;

export { StockPrice as fly_stock_price };
